@@ -145,6 +145,9 @@ public:
 	void focusNextMainWidget();
 	QPair< QByteArray, QImage > openImageFile();
 
+	void loadState(bool minimalView);
+	void storeState(bool minimalView);
+
 	void updateChatBar();
 	void openTextMessageDialog(ClientUser *p);
 	void openUserLocalNicknameDialog(const ClientUser &p);
@@ -193,6 +196,8 @@ protected:
 	qt_unique_ptr< UserLocalVolumeSlider > m_userLocalVolumeSlider;
 	qt_unique_ptr< ListenerVolumeSlider > m_listenerVolumeSlider;
 
+	static constexpr int stateVersion();
+
 	void createActions();
 	void setupGui();
 	void updateWindowTitle();
@@ -356,6 +361,7 @@ public slots:
 	/// Handles state changes like talking mode changes and mute/unmute
 	/// or priority speaker flag changes for the gui user
 	void userStateChanged();
+	void on_channelStateChanged(Channel *channel, bool forceUpdateTree);
 	void destroyUserInformation();
 	void trayAboutToShow();
 	void sendChatbarMessage(QString msg);
@@ -397,6 +403,9 @@ signals:
 	void userRemovedChannelListener(ClientUser *user, Channel *channel);
 	void transmissionModeChanged(Settings::AudioTransmit newMode);
 
+	/// Signal when channel state has been changed
+	void channelStateChanged(Channel *channel, bool forceUpdateTree);
+
 public:
 	MainWindow(QWidget *parent);
 	~MainWindow() Q_DECL_OVERRIDE;
